xquery version "3.1";

module namespace facets="http://mollenhauer-edition.de/ns/facets";

declare namespace tei="http://www.tei-c.org/ns/1.0";
declare namespace html="http://www.w3.org/1999/xhtml";
declare namespace index="https://mollenhauer-edition.de/index";

import module namespace config="https://sade.textgrid.de/ns/config" at "../../config.xqm";
import module namespace kwic="http://exist-db.org/xquery/kwic";

import module namespace search="http://mollenhauer-edition.de/ns/search" at "search.xqm";
import module namespace lang="https://sade.textgrid.de/ns/lang" at "../../lang.xqm";

declare function facets:get-facets($search)
as element(ol) {
    element ol {
        attribute class {"search-param-group"},
        attribute role {"list"},
        element h2 {
            lang:translate("filterBy")
        },
        facets:keywords($search),
        facets:genres($search)
    }
};

declare function facets:keywords($search)
as element(li)
{
    let $facet := ft:facets($search, "keyword", ())
    return
        element li {
            attribute class { "search-param" },
            element h3 { lang:translate("keywords") },
            if (count(map:keys($facet)) = 0) then
                element p { lang:translate("noKeywords") }
            else
                element fieldset {
                    attribute class {"search-list"},
                    map:for-each($facet, function($keyword, $count) {
                        facets:facet("keyword", $keyword, $count)
                    })
                }
        }
};

declare function facets:genres($search)
as element(li)
{
    let $facet := ft:facets($search, "genre", ())
    return
        element li {
            attribute class { "search-param" },
            element h3 { lang:translate("genre") },
            if (count(map:keys($facet)) = 0) then
                element p { lang:translate("noGenres") }
            else
                element fieldset {
                    attribute class {"search-list"},
                    map:for-each($facet, function($genre, $count) {
                        facets:facet("genre", $genre, $count)
                    })
                }
        }
};

declare function facets:facet($facet as xs:string, $value as xs:string, $count as xs:integer?)
as element(label)
{
    let $active-values := request:get-parameter($facet, "")
    let $display-count := string-join(("(", $count, " ",
        if ($count = 1) then
            lang:translate("textSg")
        else
            lang:translate("textPl"),
        ")"), "")
    let $checked := $active-values => filter(function($f as xs:string) {$f eq $value})
    return
        element label {
            attribute class {"search-facet"},
            element input {
                attribute class {"search-facet-checkbox"},
                attribute name {$facet},
                attribute onchange {"this.form.submit()"},
                if ($active-values => filter(function($f as xs:string) {$f eq $value})) then
                    attribute checked {"checked"}
                else (),
                attribute type {"checkbox"},
                attribute value {$value}
            },
            element span {
                attribute class {
                    if ($checked) then
                        "fa fa-minus-square"
                    else
                        "fa fa-plus-square"
                }
            },
            $value, $display-count
        }
};
