import 'bootstrap/js/dist/dropdown';
import 'bootstrap/js/dist/modal';
import 'bootstrap/js/dist/popover';
import 'bootstrap/js/dist/button';
import '@fortawesome/fontawesome-free/js/all';

import './kmg-interactive';
import './edition';
import './edition-nav';
import './register';

const dropdown = document.querySelectorAll('button.dropdown');
const toggleDropdown = function toggleDropdown(e) {
  const expanded = e.getAttribute('aria-expanded') === 'true' || false;
  e.setAttribute('aria-expanded', !expanded);
  e.classList.toggle('burger-open');
  const editionMenu = e.closest('.edition-menu');
  const nav = e.parentNode;
  const menu = nav.querySelector('ul');
  const scrollmod = window.scrollY > 170 ? 170 : window.scrollY;
  if (editionMenu) {
    menu.style.setProperty('--offset-top', `${window.scrollY + editionMenu.offsetHeight - scrollmod}px`);
  }
  nav.classList.toggle('bg-primary');
  menu.classList.toggle('hidden');
};
const clickOutside = function clickOutside(e) {
  const handleClick = (event) => {
    if (!e.contains(event.target) && e.getAttribute('aria-expanded') === 'true') {
      if ((event.target?.closest('#nav-search'))) {
        /* Do not toggle dropdown if user clicks on search bar */
      }
      else { toggleDropdown(e); }
    }
  };
  document.addEventListener('click', handleClick, true);
  return {
    destroy() {
      document.removeEventListener('click', handleClick, true);
    },
  };
};
dropdown.forEach((e) => clickOutside(e));
dropdown.forEach((e) => e.addEventListener('click', () => toggleDropdown(e)));

const scrolltop = document.querySelector('.scrolltop');
window.addEventListener('scroll', () => {
  if (window.scrollY > 170) {
    scrolltop.classList.remove('hidden');
  } else {
    scrolltop.classList.add('hidden');
  }
});

/**
 * Functionality to switch between light and dark theme. Stores system preference
 * and chosen mode in local storage.
 */
const darkmodeBtn = document.querySelector('.darktheme-button');
const prefersDarkTheme = window.matchMedia('(prefers-color-scheme: dark)');

const currentTheme = localStorage.getItem('theme');
if (currentTheme == 'dark') {
  document.body.classList.toggle('dark-theme');
} else if (currentTheme == 'light') {
  document.body.classList.toggle('light-theme');
}

darkmodeBtn.addEventListener('click', () => {
  let theme;
  document.body.classList.toggle('dark-theme');
  document.body.classList.toggle('light-theme');
  if (prefersDarkTheme.matches) {
    theme = document.body.classList.contains('light-theme')
      ? 'light'
      : 'dark';
  } else {
    theme = document.body.classList.contains('dark-theme')
      ? 'dark'
      : 'light';
  }
  localStorage.setItem('theme', theme);
});

const assignEvents = function assignTextEvents() {
  const searchHelpButtonShow = document.querySelector('.open-search-help');
  const searchHelpButtonHide = document.querySelector('.close-search-help');
  const searchHelp = document.querySelector('.search-help-dialog');

  searchHelpButtonShow.addEventListener('click', () => {
    event.preventDefault();
    searchHelp.showModal();
  });
  searchHelpButtonHide.addEventListener('click', () => {
    event.preventDefault();
    searchHelp.close();
  });
};

document.addEventListener('DOMContentLoaded', assignEvents);
